spline_curves
=============

This submodule provides the classes used to create :class:`spline <splinebox.spline_curves.Spline>` and :class:`hermite spline <splinebox.spline_curves.HermiteSpline>` objects.

.. autoclass:: splinebox.spline_curves.Spline
   :members:
   :undoc-members:

.. autofunction:: splinebox.spline_curves.padding_function

.. toctree::
   :maxdepth: 1
   :hidden:

   hermite_spline_curves.rst
